@@ -16,6 +16,18 @@ SpatialPixels = function(points, tolerance = sqrt(.Machine$double.eps),
 
 setMethod("coordinates", "SpatialPixels", function(obj) obj@coords)
 
+row.names.SpatialPixels <- function(x) {
+    ret = dimnames(slot(x, "coords"))[[1]]
+	if (is.null(ret))
+		ret = seq_len(nrow(x@coords))
+	ret
+}
+
+row.names.SpatialGrid <- function(x) {
+	warning("row.names order might not reflect grid sequence!")
+	1:prod(x@grid@cells.dim)
+}
+
 SpatialGrid = function(grid, proj4string = CRS(as.character(NA))) {
 	pts = boguspoints(grid)
 	pts@bbox[,1] = pts@bbox[,1] - 0.5 * grid@cellsize
@@ -263,3 +275,6 @@ IDvaluesSpatialPixels <- function(obj) {
 	res <- as.matrix(sapply(cc, as.integer))
 	paste("g", res, sep="")
 }
+
+length.SpatialPixels = function(x) { nrow(x@coords) }
+length.SpatialGrid = function(x) { .NumberOfCells(x@grid) }
