@@ -338,8 +338,10 @@ function (x, y, z, subscripts, at = pretty(z), shrink, labels = NULL,
 	z <- as.numeric(z[subscripts])
 	zcol <- as.numeric(zcol[subscripts])
 
-	if (is(grid.polygons, "SpatialLines"))
-		sp.panel.layout(sp.layout, panel.number())
+	#EJP,2010-10-8: 
+	#if (is(grid.polygons, "SpatialLines"))
+	#	sp.panel.layout(sp.layout, panel.number())
+	sp.panel.layout(sp.layout, panel.number(), first = TRUE)
 	if (any(subscripts)) {
 		if (is(grid.polygons, "SpatialLines")) {
 			sp.lines3 = function(x, col, ...) panel.lines(coordinates(x), col = col, ...)
@@ -372,8 +374,10 @@ function (x, y, z, subscripts, at = pretty(z), shrink, labels = NULL,
    			}
 		}
 	}
-	if (!is(grid.polygons, "SpatialLines"))
-		sp.panel.layout(sp.layout, panel.number())
+	# EJP, 2010-10-8
+	#if (!is(grid.polygons, "SpatialLines"))
+	#	sp.panel.layout(sp.layout, panel.number())
+	sp.panel.layout(sp.layout, panel.number())
 }
 
 panel.pointsplot = function(x, y, subscripts, col, sp.layout, ...) {
